py-mactypes manual | 1. Introduction

#

## 1. Introduction

### About mactypes

The `mactypes` module provides user-friendly wrappers for Apple event descriptors that do not have direct equivalents in the Python language. It contains Python classes for specifying filesystem objects and locations, and unit type values (lengths, weights, etc.), and is used in conjunction with the `appscript`, `osax` and/or `aem` modules.

### Notes

Be aware that most scriptable applications do not use or understand POSIX paths, and while the Apple Event Manager does provide some built-in coercions for converting between path strings and alias/file objects, these work with HFS paths only. Therefore, when specifying files and folders to scriptable applications, use `mactypes.Alias` and `mactypes.File` objects - not path strings - unless otherwise indicated.